package org.jk.system.mapper;



import org.jk.system.domain.ProjectApplication;
import org.jk.system.domain.SysProjectApp;

import java.util.List;

public interface SysProjectAppMapper {

    /**
     * 查询【请填写功能名称】
     *
     * @param appId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public SysProjectApp selectSysProjectAppByAppId(String appId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysProjectApp 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<SysProjectApp> selectSysProjectAppList(SysProjectApp sysProjectApp);

    /**
     * 新增【请填写功能名称】
     *
     * @param sysProjectApp 【请填写功能名称】
     * @return 结果
     */
    public int insertSysProjectApp(SysProjectApp sysProjectApp);

    /**
     * 修改【请填写功能名称】
     *
     * @param sysProjectApp 【请填写功能名称】
     * @return 结果
     */
    public int updateSysProjectApp(SysProjectApp sysProjectApp);

    /**
     * 删除【请填写功能名称】
     *
     * @param projectId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteSysProjectAppByProjectId(String projectId);

    /**
     * 通过APPID删除关联信息
     * @param appId
     * @return
     */
    public int  deleteSysProjectAppByAppId(String appId);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param projectIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysProjectAppByProjectIds(String[] projectIds);

    public List<ProjectApplication> selectSysProjectApplicationList(SysProjectApp sysProjectApp);


}
